import { HeadersOption } from '@managed-api/commons-core';
import { Branch } from '../definitions/branch';
import { CommonError, ErrorStrategyOption } from '../errorStrategy';
export interface GetBranchesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: number | string;
    /**
     * Return list of branches containing the search string. You can use ^term and term$ to find branches that begin and end with term respectively.
     */
    search?: string;
}
export interface GetBranchesResponseOK extends Array<Branch> {
}
export interface GetBranchesResponseError extends CommonError {
}
export interface GetBranchRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: number | string;
    /**
     * Name of the branch.
     */
    branch: string;
}
export interface GetBranchResponseOK extends Branch {
}
export interface GetBranchResponseError extends CommonError {
}
export interface CreateBranchRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: number;
    body: {
        /**
         * Name of the branch.
         */
        branch: string;
        /**
         * Branch name or commit SHA to create branch from.
         */
        ref: string;
    };
}
export interface CreateBranchResponseOK extends Branch {
}
export interface CreateBranchResponseError extends CommonError {
}
export interface DeleteBranchRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: number | string;
    /**
     * Name of the branch.
     */
    branch: string;
}
export declare type DeleteBranchResponseOK = undefined;
export interface DeleteBranchResponseError extends CommonError {
}
export interface DeleteMergedBranchesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: number | string;
}
export declare type DeleteMergedBranchesResponseOK = undefined;
export interface DeleteMergedBranchesResponseError extends CommonError {
}
//# sourceMappingURL=branch.d.ts.map