import { HeadersOption } from '@managed-api/commons-core';
import { Status } from '../../definitions/status';
import { CommonError, ErrorStrategyOption } from '../../errorStrategy';
export interface GetStatusesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    /**
     * The commit SHA or name of a repository branch or tag.
     */
    sha: string;
    /**
     * The name of a repository branch or tag or, if not given, the default branch.
     */
    ref?: string;
    /**
     * Filter by build stage, for example, test.
     */
    stage?: string;
    /**
     * Filter by job name, for example, bundler:audit.
     */
    name?: string;
    /**
     * Return all statuses, not only the latest ones.
     */
    all?: boolean;
    /**
     * The pagination parameters page and per_page can be used to restrict the list of references.
     */
    page?: number;
    /**
     * The pagination parameters page and per_page can be used to restrict the list of references.
     */
    per_page?: number;
}
export interface GetStatusesResponseOK extends Array<Status> {
}
export interface GetStatusesResponseError extends CommonError {
}
export interface CreateBuildStatusRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    /**
     * The commit SHA.
     */
    sha: string;
    body: {
        /**
         * The state of the status. Can be one of the following: pending, running, success, failed, canceled.
         */
        state: 'pending' | 'running' | 'success' | 'failed' | 'canceled';
        /**
         * The ref (branch or tag) to which the status refers.
         */
        ref?: string;
        /**
         * The label to differentiate this status from the status of other systems. Default value is default.
         */
        name?: string;
        /**
         * The label to differentiate this status from the status of other systems. Default value is default.
         */
        context?: string;
        /**
         * The target URL to associate with this status.
         */
        target_url?: string;
        /**
         * The short description of the status.
         */
        description?: string;
        /**
         * The total code coverage.
         */
        coverage?: number;
        /**
         * The ID of the pipeline to set status. Use in case of several pipeline on same SHA.
         */
        pipeline_id?: number;
    };
}
export interface CreateBuildStatusResponseOK extends Status {
}
export interface CreateBuildStatusResponseError extends CommonError {
}
//# sourceMappingURL=status.d.ts.map