import { HeadersOption } from '@managed-api/commons-core';
import { TodoItem } from '../definitions/epic';
import { Issue, PromoteToEpic, UserAgent } from '../definitions/issue';
import { MergeRequest } from '../definitions/merge_request';
import { Timestats } from '../definitions/time_stats';
import { User } from '../definitions/user';
import { CommonError, ErrorStrategyOption } from '../errorStrategy';
export interface GetIssuesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Return issues assigned to the given user id. Mutually exclusive with assignee_username. None returns unassigned issues. Any returns issues with an assignee.
     */
    assignee_id?: number;
    /**
     * Return issues assigned to the given username. Similar to assignee_id and mutually exclusive with assignee_id. In GitLab CE, the assignee_username array should only contain a single value. Otherwise, an invalid parameter error is returned.
     */
    assignee_username?: string[];
    /**
     * Return issues created by the given user id. Mutually exclusive with author_username. Combine with scope=all or scope=assigned_to_me.
     */
    author_id?: number;
    /**
     * Return issues created by the given username. Similar to author_id and mutually exclusive with author_id.
     */
    author_username?: string;
    /**
     * Filter confidential or public issues.
     */
    confidential?: boolean;
    /**
     * Return issues created on or after the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z).
     */
    created_after?: string;
    /**
     * Return issues created on or before the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z).
     */
    created_before?: string;
    /**
     * Return issues that have no due date, are overdue, or whose due date is this week, this month, or between two weeks ago and next month. Accepts: 0 (no due date), any, today, tomorrow, overdue, week, month, next_month_and_previous_two_weeks.
     */
    due_date?: '0' | 'any' | 'today' | 'tomorrow' | 'overdue' | 'week' | 'month' | 'next_month_and_previous_two_weeks';
    /**
     * Return issues associated with the given epic ID. None returns issues that are not associated with an epic. Any returns issues that are associated with an epic.
     */
    epic_id?: number;
    /**
     * Return only the issues having the given iid.
     */
    iids?: number[];
    /**
     * Modify the scope of the search attribute. title, description, or a string joining them with comma. Default is title,description.
     */
    in_param?: string;
    /**
     * Filter to a given type of issue. One of issue, incident, or test_case.
     */
    issue_type?: string;
    /**
     * Return issues assigned to the given iteration ID. None returns issues that do not belong to an iteration. Any returns issues that belong to an iteration. Mutually exclusive with iteration_title.
     */
    iteration_id?: number;
    /**
     * Return issues assigned to the iteration with the given title. Similar to iteration_id and mutually exclusive with iteration_id.
     */
    iteration_title?: string;
    /**
     * Comma-separated list of label names, issues must have all labels to be returned. None lists all issues with no labels. Any lists all issues with at least one label. No+Label (Deprecated) lists all issues with no labels. Predefined names are case-insensitive.
     */
    labels?: string;
    /**
     * The milestone title. None lists all issues with no milestone. Any lists all issues that have an assigned milestone. Using None or Any will be deprecated in the future. Please use milestone_id attribute instead. milestone and milestone_id are mutually exclusive.
     */
    milestone?: string;
    /**
     * Returns issues assigned to milestones with a given timebox value (None, Any, Upcoming, and Started). None lists all issues with no milestone. Any lists all issues that have an assigned milestone. Upcoming lists all issues assigned to milestones due in the future. Started lists all issues assigned to open, started milestones. milestone and milestone_id are mutually exclusive.
     */
    milestone_id?: string;
    /**
     * Return issues reacted by the authenticated user by the given emoji. None returns issues not given a reaction. Any returns issues given at least one reaction.
     */
    my_reaction_emoji?: string;
    /**
     * Return issues only from non-archived projects. If false, the response returns issues from both archived and non-archived projects. Default is true.
     */
    non_archived?: boolean;
    /**
     * Return issues that do not match the parameters supplied. Accepts: assignee_id, assignee_username, author_id, author_username, iids, iteration_id, iteration_title, labels, milestone, milestone_id and weight.
     */
    not?: string | number;
    /**
     * Return issues ordered by created_at, due_date, label_priority, milestone_due, popularity, priority, relative_position, title, updated_at, or weight fields. Default is created_at.
     */
    order_by?: 'created_at' | 'due_date' | 'label_priority' | 'milestone_due' | 'popularity' | 'priority' | 'relative_position' | 'title' | 'updated_at' | 'weight';
    /**
     * Return issues for the given scope: created_by_me, assigned_to_me or all. Defaults to created_by_me.
     */
    scope?: string;
    /**
     * Search issues against their title and description.
     */
    search?: string;
    /**
     * Return issues sorted in asc or desc order. Default is desc.
     */
    sort?: 'asc' | 'desc';
    /**
     * Return all issues or just those that are opened or closed.
     */
    state?: 'opened' | 'closed';
    /**
     * Return issues updated on or after the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z).
     */
    updated_after?: string;
    /**
     * Return issues updated on or before the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z).
     */
    updated_before?: string;
    /**
     * Return issues with the specified weight. None returns issues with no weight assigned. Any returns issues with a weight assigned.
     */
    weight?: number;
    /**
     * If true, the response returns more details for each label in labels field: :name, :color, :description, :description_html, :text_color. Default is false. The description_html attribute was introduced in GitLab 12.7
     */
    with_labels_details?: boolean;
}
export interface GetIssuesResponseOK extends Array<Issue> {
}
export interface GetIssuesResponseError extends CommonError {
}
export interface GetGroupIssuesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Return issues assigned to the given user id. Mutually exclusive with assignee_username. None returns unassigned issues. Any returns issues with an assignee.
     */
    assignee_id?: number;
    /**
     * Return issues assigned to the given username. Similar to assignee_id and mutually exclusive with assignee_id. In GitLab CE, the assignee_username array should only contain a single value. Otherwise, an invalid parameter error is returned.
     */
    assignee_username?: string[];
    /**
     * Return issues created by the given user id. Mutually exclusive with author_username. Combine with scope=all or scope=assigned_to_me.
     */
    author_id?: number;
    /**
     * Return issues created by the given username. Similar to author_id and mutually exclusive with author_id.
     */
    author_username?: string;
    /**
     * Filter confidential or public issues.
     */
    confidential?: boolean;
    /**
     * Return issues created on or after the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
     */
    created_after?: string;
    /**
     * Return issues created on or before the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
     */
    created_before?: string;
    /**
     * Return issues that have no due date, are overdue, or whose due date is this week, this month, or between two weeks ago and next month. Accepts: 0 (no due date), any, today, tomorrow, overdue, week, month, next_month_and_previous_two_weeks.
     */
    due_date?: '0' | 'any' | 'today' | 'tomorrow' | 'overdue' | 'week' | 'month' | 'next_month_and_previous_two_weeks';
    /**
     * Return issues associated with the given epic ID. None returns issues that are not associated with an epic. Any returns issues that are associated with an epic. (Introduced in GitLab 13.6)
     */
    epic_id?: number;
    /**
     * The ID or URL-encoded path of the group owned by the authenticated user
     */
    id: number | string;
    /**
     * Return only the issues having the given iid
     */
    iids?: number[];
    /**
     * Filter to a given type of issue. One of issue, incident, or test_case. (Introduced in GitLab 13.12)
     */
    issue_type?: string;
    /**
     * Return issues assigned to the given iteration ID. None returns issues that do not belong to an iteration. Any returns issues that belong to an iteration. Mutually exclusive with iteration_title. (Introduced in GitLab 13.6)
     */
    iteration_id?: number;
    /**
     * Return issues assigned to the iteration with the given title. Similar to iteration_id and mutually exclusive with iteration_id. (Introduced in GitLab 13.6)
     */
    iteration_title?: string;
    /**
     * Comma-separated list of label names, issues must have all labels to be returned. None lists all issues with no labels. Any lists all issues with at least one label. No+Label (Deprecated) lists all issues with no labels. Predefined names are case-insensitive.
     */
    labels?: string;
    /**
     * The milestone title. None lists all issues with no milestone. Any lists all issues that have an assigned milestone.
     */
    milestone?: string;
    /**
     * Return issues reacted by the authenticated user by the given emoji. None returns issues not given a reaction. Any returns issues given at least one reaction.
     */
    my_reaction_emoji?: string;
    /**
     * Return issues from non archived projects. Default is true. (Introduced in GitLab 12.8)
     */
    non_archived?: boolean;
    /**
     * Return issues that do not match the parameters supplied. Accepts: labels, milestone, author_id, author_username, assignee_id, assignee_username, my_reaction_emoji, search, in
     */
    not?: string | number;
    /**
     * Return issues ordered by created_at, updated_at, priority, due_date, relative_position, label_priority, milestone_due, popularity, weight fields. Default is created_at
     */
    order_by?: 'created_at' | 'updated_at' | 'priority' | 'due_date' | 'relative_position' | 'label_priority' | 'milestone_due' | 'popularity' | 'weight';
    /**
     * Return issues for the given scope: created_by_me, assigned_to_me or all. Defaults to all.
     */
    scope?: string;
    /**
     * Search group issues against their title and description
     */
    search?: string;
    /**
     * Return issues sorted in asc or desc order. Default is desc
     */
    sort?: 'asc' | 'desc';
    /**
     * Return all issues or just those that are opened or closed
     */
    state?: string;
    /**
     * Return issues updated on or after the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
     */
    updated_after?: string;
    /**
     * Return issues updated on or before the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
     */
    updated_before?: string;
    /**
     * Return issues with the specified weight. None returns issues with no weight assigned. Any returns issues with a weight assigned.
     */
    weight?: number;
    /**
     * If true, the response returns more details for each label in labels field: :name, :color, :description, :description_html, :text_color. Default is false. The description_html attribute was introduced in GitLab 12.7
     */
    with_labels_details?: boolean;
}
export interface GetGroupIssuesResponseOK extends Array<Issue> {
}
export interface GetGroupIssuesResponseError extends CommonError {
}
export interface GetProjectIssuesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Return issues assigned to the given user id. Mutually exclusive with assignee_username. None returns unassigned issues. Any returns issues with an assignee.
     */
    assignee_id?: number;
    /**
     * Return issues assigned to the given username. Similar to assignee_id and mutually exclusive with assignee_id. In GitLab CE, the assignee_username array should only contain a single value. Otherwise, an invalid parameter error is returned.
     */
    assignee_username?: string[];
    /**
     * Return issues created by the given user id. Mutually exclusive with author_username. Combine with scope=all or scope=assigned_to_me.
     */
    author_id?: number;
    /**
     * Return issues created by the given username. Similar to author_id and mutually exclusive with author_id.
     */
    author_username?: string;
    /**
     * Filter confidential or public issues.
     */
    confidential?: boolean;
    /**
     * Return issues created on or after the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
     */
    created_after?: string;
    /**
     * Return issues created on or before the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
     */
    created_before?: string;
    /**
     * Return issues that have no due date, are overdue, or whose due date is this week, this month, or between two weeks ago and next month. Accepts: 0 (no due date), any, today, tomorrow, overdue, week, month, next_month_and_previous_two_weeks.
     */
    due_date?: '0' | 'any' | 'today' | 'tomorrow' | 'overdue' | 'week' | 'month' | 'next_month_and_previous_two_weeks';
    /**
     * Return issues associated with the given epic ID. None returns issues that are not associated with an epic. Any returns issues that are associated with an epic. (Introduced in GitLab 13.6)
     */
    epic_id?: number;
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * Return only the issues having the given iid
     */
    iids?: number[];
    /**
     * Filter to a given type of issue. One of issue, incident, or test_case. (Introduced in GitLab 13.12)
     */
    issue_type?: string;
    /**
     * Return issues assigned to the given iteration ID. None returns issues that do not belong to an iteration. Any returns issues that belong to an iteration. Mutually exclusive with iteration_title. (Introduced in GitLab 13.6)
     */
    iteration_id?: number;
    /**
     * Return issues assigned to the iteration with the given title. Similar to iteration_id and mutually exclusive with iteration_id. (Introduced in GitLab 13.6)
     */
    iteration_title?: string;
    /**
     * Comma-separated list of label names, issues must have all labels to be returned. None lists all issues with no labels. Any lists all issues with at least one label. No+Label (Deprecated) lists all issues with no labels. Predefined names are case-insensitive.
     */
    labels?: string;
    /**
     * The milestone title. None lists all issues with no milestone. Any lists all issues that have an assigned milestone.
     */
    milestone?: string;
    /**
     * Return issues reacted by the authenticated user by the given emoji. None returns issues not given a reaction. Any returns issues given at least one reaction.
     */
    my_reaction_emoji?: string;
    /**
     * Return issues that do not match the parameters supplied. Accepts: labels, milestone, author_id, author_username, assignee_id, assignee_username, my_reaction_emoji, search, in
     */
    not?: string | number;
    /**
     * Return issues ordered by created_at, updated_at, priority, due_date, relative_position, label_priority, milestone_due, popularity, weight fields. Default is created_at
     */
    order_by?: 'created_at' | 'updated_at' | 'priority' | 'due_date' | 'relative_position' | 'label_priority' | 'milestone_due' | 'popularity' | 'weight';
    /**
     * Return issues for the given scope: created_by_me, assigned_to_me or all. Defaults to all.
     */
    scope?: string;
    /**
     * Search project issues against their title and description
     */
    search?: string;
    /**
     * Return issues sorted in asc or desc order. Default is desc
     */
    sort?: 'asc' | 'desc';
    /**
     * Return all issues or just those that are opened or closed
     */
    state?: string;
    /**
     * Return issues updated on or after the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
     */
    updated_after?: string;
    /**
     * Return issues updated on or before the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
     */
    updated_before?: string;
    /**
     * Return issues with the specified weight. None returns issues with no weight assigned. Any returns issues with a weight assigned.
     */
    weight?: number;
    /**
     * If true, the response returns more details for each label in labels field: :name, :color, :description, :description_html, :text_color. Default is false. description_html was introduced in GitLab 12.7
     */
    with_labels_details?: boolean;
}
export interface GetProjectIssuesResponseOK extends Array<Issue> {
}
export interface GetProjectIssuesResponseError extends CommonError {
}
export interface GetIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the issue
     */
    id: number;
}
export interface GetIssueResponseOK extends Issue {
}
export interface GetIssueResponseError extends CommonError {
}
export interface GetProjectIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
}
export interface GetProjectIssueResponseOK extends Issue {
}
export interface GetProjectIssueResponseError extends CommonError {
}
export interface CreateIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    body: {
        /**
         * The ID of the user to assign the issue to. Only appears on GitLab Free.
         */
        assignee_id?: number;
        /**
         * The IDs of the users to assign the issue to.
         */
        assignee_ids?: number[];
        /**
         * Set an issue to be confidential. Default is false.
         */
        confidential?: boolean;
        /**
         * When the issue was created. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z. Requires administrator or project/group owner rights.
         */
        created_at?: string;
        /**
         * The description of an issue. Limited to 1,048,576 characters.
         */
        description?: string;
        /**
         * The ID of a discussion to resolve. This fills out the issue with a default description and mark the discussion as resolved. Use in combination with merge_request_to_resolve_discussions_of.
         */
        discussion_to_resolve?: string;
        /**
         * The due date. Date time string in the format YYYY-MM-DD, for example 2016-03-11
         */
        due_date?: string;
        /**
         * ID of the epic to add the issue to. Valid values are greater than or equal to 0.
         */
        epic_id?: number;
        /**
         * IID of the epic to add the issue to. Valid values are greater than or equal to 0. (deprecated, scheduled for removal in API version 5)
         */
        epic_iid?: number;
        /**
         * The internal ID of the project's issue (requires administrator or project owner rights)
         */
        iid?: number | string;
        /**
         * The type of issue. One of issue, incident, or test_case. Default is issue.
         */
        issue_type?: string;
        /**
         * Comma-separated label names for an issue
         */
        labels?: string;
        /**
         * The IID of a merge request in which to resolve all issues. This fills out the issue with a default description and mark all discussions as resolved. When passing a description or title, these values take precedence over the default values.
         */
        merge_request_to_resolve_discussions_of?: number;
        /**
         * The global ID of a milestone to assign issue. To find the milestone_id associated with a milestone, view an issue with the milestone assigned and use the API to retrieve the issue's details.
         */
        milestone_id?: number;
        /**
         * The title of an issue
         */
        title: string;
        /**
         * The weight of the issue. Valid values are greater than or equal to 0.
         */
        weight?: number;
    };
}
export interface CreateIssueResponseOK extends Issue {
}
export interface CreateIssueResponseError extends CommonError {
}
export interface EditIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
    body: {
        /**
         * Comma-separated label names to add to an issue.
         */
        add_labels?: string;
        /**
         * The ID of the user(s) to assign the issue to. Set to 0 or provide an empty value to unassign all assignees.
         */
        assignee_ids?: number[];
        /**
         * Updates an issue to be confidential
         */
        confidential?: boolean;
        /**
         * The description of an issue. Limited to 1,048,576 characters.
         */
        description?: string;
        /**
         * Flag indicating if the issue's discussion is locked. If the discussion is locked only project members can add or edit comments.
         */
        discussion_locked?: boolean;
        /**
         * The due date. Date time string in the format YYYY-MM-DD, for example 2016-03-11
         */
        due_date?: string;
        /**
         * ID of the epic to add the issue to. Valid values are greater than or equal to 0.
         */
        epic_id?: number;
        /**
         * IID of the epic to add the issue to. Valid values are greater than or equal to 0. (deprecated, scheduled for removal in API version 5)
         */
        epic_iid?: number;
        /**
         * Updates the type of issue. One of issue, incident, or test_case.
         */
        issue_type?: string;
        /**
         * Comma-separated label names for an issue. Set to an empty string to unassign all labels.
         */
        labels?: string;
        /**
         * The global ID of a milestone to assign the issue to. Set to 0 or provide an empty value to unassign a milestone.
         */
        milestone_id?: number;
        /**
         * Comma-separated label names to remove from an issue.
         */
        remove_labels?: string;
        /**
         * The state event of an issue. Set close to close the issue and reopen to reopen it
         */
        state_event?: string;
        /**
         * The title of an issue
         */
        title?: string;
        /**
         * When the issue was updated. Date time string, ISO 8601 formatted, for example 2016-03-11T03:45:40Z (requires administrator or project owner rights). Empty string or null values are not accepted.
         */
        updated_at?: string;
        /**
         * The weight of the issue. Valid values are greater than or equal to 0. 0
         */
        weight?: number;
    };
}
export interface EditIssueResponseOK extends Issue {
}
export interface EditIssueResponseError extends CommonError {
}
export interface DeleteIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
}
export declare type DeleteIssueResponseOK = undefined;
export interface DeleteIssueResponseError extends CommonError {
}
export interface ReorderIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of the project's issue
     */
    issue_iid: number;
    body: {
        /**
         * The ID of a project's issue that should be placed after this issue
         */
        move_after_id?: number;
        /**
         * The ID of a project's issue that should be placed before this issue
         */
        move_before_id?: number;
    };
}
export declare type ReorderIssueResponseOK = undefined;
export interface ReorderIssueResponseError extends CommonError {
}
export interface MoveIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
    body: {
        /**
         * The ID of the new project
         */
        to_project_id: number;
    };
}
export interface MoveIssueResponseOK extends Issue {
}
export interface MoveIssueResponseError extends CommonError {
}
export interface CloneIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: number | string;
    /**
     * Internal ID of a project's issue.
     */
    issue_iid: number;
    body: {
        /**
         * ID of the new project.
         */
        to_project_id: number;
        /**
         * Clone the issue with notes. Default is false.
         */
        with_notes?: boolean;
    };
}
export interface CloneIssueResponseOK extends Issue {
}
export interface CloneIssueResponseError extends CommonError {
}
export interface SubscribeToIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
}
export interface SubscribeToIssueResponseOK extends Issue {
}
export interface SubscribeToIssueResponseError extends CommonError {
}
export interface UnsubscribeFromIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
}
export interface UnsubscribeFromIssueResponseOK extends Issue {
}
export interface UnsubscribeFromIssueResponseError extends CommonError {
}
export interface CreateTodoItemRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
}
export interface CreateTodoItemResponseOK extends TodoItem {
}
export interface CreateTodoItemResponseError extends CommonError {
}
export interface PromoteToEpicRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
    /**
     * The content of a note. Must contain /promote at the start of a new line.
     */
    body: string;
}
export interface PromoteToEpicResponseOK extends PromoteToEpic {
}
export interface PromoteToEpicResponseError extends CommonError {
}
export interface SetTimeEstimateForIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
    body: {
        /**
         * The duration in human format. e.g: 3h30m
         */
        duration: string;
    };
}
export interface SetTimeEstimateForIssueResponseOK extends Timestats {
}
export interface SetTimeEstimateForIssueResponseError extends CommonError {
}
export interface ResetTimeEstimateForIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
}
export interface ResetTimeEstimateForIssueResponseOK extends Timestats {
}
export interface ResetTimeEstimateForIssueResponseError extends CommonError {
}
export interface AddSpentTimeForIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
    body: {
        /**
         * A summary of how the time was spent
         */
        summary?: string;
        /**
         * The duration in human format. e.g: 3h30m
         */
        duration: string;
    };
}
export interface AddSpentTimeForIssueResponseOK extends Timestats {
}
export interface AddSpentTimeForIssueResponseError extends CommonError {
}
export interface ResetSpentTimeForIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
}
export interface ResetSpentTimeForIssueResponseOK extends Timestats {
}
export interface ResetSpentTimeForIssueResponseError extends CommonError {
}
export interface GetTimeTrackingStatsForIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
}
export interface GetTimeTrackingStatsForIssueResponseOK extends Timestats {
}
export interface GetTimeTrackingStatsForIssueResponseError extends CommonError {
}
export interface GetMergeRequestsRelatedToIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
}
export interface GetMergeRequestsRelatedToIssueResponseOK extends Array<MergeRequest> {
}
export interface GetMergeRequestsRelatedToIssueResponseError extends CommonError {
}
export interface GetMergeRequestsThatClosedAnIssueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
}
export interface GetMergeRequestsThatClosedAnIssueResponseOK extends Array<MergeRequest> {
}
export interface GetMergeRequestsThatClosedAnIssueResponseError extends CommonError {
}
export interface GetParticipantsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
}
export interface GetParticipantsResponseOK extends Array<User> {
}
export interface GetParticipantsResponseError extends CommonError {
}
export interface GetUserAgentDetailsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
}
export interface GetUserAgentDetailsResponseOK extends UserAgent {
}
export interface GetUserAgentDetailsResponseError extends CommonError {
}
//# sourceMappingURL=issue.d.ts.map