import { HeadersOption } from '@managed-api/commons-core';
import { Issue } from '../../definitions/issue';
import { IssueLinkCreateDelete } from '../../definitions/link';
import { CommonError, ErrorStrategyOption } from '../../errorStrategy';
export interface GetRelationsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
}
export interface GetRelationsResponseOK extends Array<Issue> {
}
export interface GetRelationsResponseError extends CommonError {
}
export interface CreateLinkRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
    body: {
        /**
         * The ID or URL-encoded path of the project of a target project
         */
        target_project_id: number | string;
        /**
         * The internal ID of a target project's issue
         */
        target_issue_iid: number | string;
        /**
         * The type of the relation ("relates_to", "blocks", "is_blocked_by"), defaults to "relates_to").
         */
        link_type?: 'relates_to' | 'blocks' | 'is_blocked_by';
    };
}
export interface CreateLinkResponseOK extends IssueLinkCreateDelete {
}
export interface CreateLinkResponseError extends CommonError {
}
export interface DeleteLinkRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user
     */
    id: number | string;
    /**
     * The internal ID of a project's issue
     */
    issue_iid: number;
    /**
     * The ID of an issue relationship
     */
    issue_link_id: number | string;
    /**
     * The type of the relation (relates_to, blocks, is_blocked_by), defaults to relates_to
     */
    link_type?: 'relates_to' | 'blocks' | 'is_blocked_by';
}
export interface DeleteLinkResponseOK extends IssueLinkCreateDelete {
}
export interface DeleteLinkResponseError extends CommonError {
}
//# sourceMappingURL=issue.d.ts.map