import { HeadersOption } from '@managed-api/commons-core';
import { CreateUpdateFile, File, FileBlame } from '../../definitions/file';
import { CommonError, ErrorStrategyOption } from '../../errorStrategy';
export interface GetFileRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    /**
     * URL encoded full path to new file. Ex. lib%2Fclass%2Erb.
     */
    file_path: string;
    /**
     * The name of branch, tag or commit.
     */
    ref: string;
}
export interface GetFileResponseOK extends File {
}
export interface GetFileResponseError extends CommonError {
}
export interface GetFileBlameRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    /**
     * URL encoded full path to new file. Ex. lib%2Fclass%2Erb.
     */
    file_path: string;
    /**
     * The name of branch, tag or commit.
     */
    ref: string;
}
export interface GetFileBlameResponseOK extends Array<FileBlame> {
}
export interface GetFileBlameResponseError extends CommonError {
}
export interface GetRawFileRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    /**
     * URL encoded full path to new file. Ex. lib%2Fclass%2Erb.
     */
    file_path: string;
    /**
     * The name of branch, tag or commit.
     */
    ref: string;
}
export declare type GetRawFileResponseOK = string;
export interface GetRawFileResponseError extends CommonError {
}
export interface CreateFileRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    /**
     * URL encoded full path to new file. Ex. lib%2Fclass%2Erb.
     */
    file_path: string;
    body: {
        /**
         * Name of the new branch to create. The commit is added to this branch.
         */
        branch: string;
        /**
         * Name of the base branch to create the new branch from.
         */
        start_branch?: string;
        /**
         * Change encoding to base64. Default is text.
         */
        encoding?: string;
        /**
         * The commit author’s email address.
         */
        author_email?: string;
        /**
         * The commit author’s name.
         */
        author_name?: string;
        /**
         * The file’s content.
         */
        content: string;
        /**
         * The commit message.
         */
        commit_message: string;
    };
}
export interface CreateFileResponseOK extends CreateUpdateFile {
}
export interface CreateFileResponseError extends CommonError {
}
export interface UpdateFileRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    /**
     * URL encoded full path to new file. Ex. lib%2Fclass%2Erb.
     */
    file_path: string;
    body: {
        /**
         * Name of the new branch to create. The commit is added to this branch.
         */
        branch: string;
        /**
         * Name of the base branch to create the new branch from.
         */
        start_branch?: string;
        /**
         * Change encoding to base64. Default is text.
         */
        encoding?: string;
        /**
         * The commit author’s email address.
         */
        author_email?: string;
        /**
         * The commit author’s name.
         */
        author_name?: string;
        /**
         * The file’s content.
         */
        content: string;
        /**
         * The commit message.
         */
        commit_message: string;
        /**
         * Last known file commit ID.
         */
        last_commit_id?: string;
    };
}
export interface UpdateFileResponseOK extends CreateUpdateFile {
}
export interface UpdateFileResponseError extends CommonError {
}
export interface DeleteFileRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or URL-encoded path of the project owned by the authenticated user.
     */
    id: string | number;
    /**
     * URL encoded full path to new file. Ex. lib%2Fclass%2Erb.
     */
    file_path: string;
    body: {
        /**
         * Name of the new branch to create. The commit is added to this branch.
         */
        branch: string;
        /**
         * Name of the base branch to create the new branch from.
         */
        start_branch?: string;
        /**
         * The commit author’s email address.
         */
        author_email?: string;
        /**
         * The commit author’s name.
         */
        author_name?: string;
        /**
         * The commit message.
         */
        commit_message: string;
        /**
         * Last known file commit ID.
         */
        last_commit_id?: string;
    };
}
export declare type DeleteFileResponseOK = undefined;
export interface DeleteFileResponseError extends CommonError {
}
//# sourceMappingURL=file.d.ts.map